.. pyFTLE documentation master file, created by
   sphinx-quickstart on Sun Nov  9 07:30:41 2025.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to pyFTLE's documentation!
===================================

.. include:: ../../README.md
   :parser: myst_parser.sphinx_

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   pyftle

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
